@@ -40,22 +40,15 @@ namespace QuantLib {
                                      const ext::shared_ptr<IborIndex>& index,
                                      Rate fixedRate,
                                      const Period& forwardStart)
-    : swapTenor_(swapTenor), iborIndex_(index),
-      fixedRate_(fixedRate), forwardStart_(forwardStart),
-      settlementDays_(Null<Natural>()),
-      fixedCalendar_(index->fixingCalendar()),
+    : swapTenor_(swapTenor), iborIndex_(index), fixedRate_(fixedRate), forwardStart_(forwardStart),
+      settlementDays_(Null<Natural>()), fixedCalendar_(index->fixingCalendar()),
       floatCalendar_(index->fixingCalendar()),
-      type_(Swap::Payer), nominal_(1.0),
+
       floatTenor_(index->tenor()),
-      fixedConvention_(ModifiedFollowing),
-      fixedTerminationDateConvention_(ModifiedFollowing),
+
       floatConvention_(index->businessDayConvention()),
       floatTerminationDateConvention_(index->businessDayConvention()),
-      fixedRule_(DateGeneration::Backward), floatRule_(DateGeneration::Backward),
-      fixedEndOfMonth_(false), floatEndOfMonth_(false),
-      fixedFirstDate_(Date()), fixedNextToLastDate_(Date()),
-      floatFirstDate_(Date()), floatNextToLastDate_(Date()),
-      floatSpread_(0.0),
+
       floatDayCount_(index->dayCounter()) {}
 
     MakeVanillaSwap::operator VanillaSwap() const {
@@ -156,12 +149,10 @@ namespace QuantLib {
 
         Rate usedFixedRate = fixedRate_;
         if (fixedRate_ == Null<Rate>()) {
-            VanillaSwap temp(type_, 100.00,
-                             fixedSchedule,
+            VanillaSwap temp(type_, 100.00, fixedSchedule,
                              0.0, // fixed rate
-                             fixedDayCount,
-                             floatSchedule, iborIndex_,
-                             floatSpread_, floatDayCount_);
+                             fixedDayCount, floatSchedule, iborIndex_, floatSpread_, floatDayCount_,
+                             boost::none, useIndexedCoupons_);
             if (engine_ == nullptr) {
                 Handle<YieldTermStructure> disc =
                                         iborIndex_->forwardingTermStructure();
@@ -178,12 +169,9 @@ namespace QuantLib {
             usedFixedRate = temp.fairRate();
         }
 
-        ext::shared_ptr<VanillaSwap> swap(new
-            VanillaSwap(type_, nominal_,
-                        fixedSchedule,
-                        usedFixedRate, fixedDayCount,
-                        floatSchedule,
-                        iborIndex_, floatSpread_, floatDayCount_));
+        ext::shared_ptr<VanillaSwap> swap(new VanillaSwap(
+            type_, nominal_, fixedSchedule, usedFixedRate, fixedDayCount, floatSchedule, iborIndex_,
+            floatSpread_, floatDayCount_, boost::none, useIndexedCoupons_));
 
         if (engine_ == nullptr) {
             Handle<YieldTermStructure> disc =
@@ -358,4 +346,14 @@ namespace QuantLib {
         return *this;
     }
 
+    MakeVanillaSwap& MakeVanillaSwap::withIndexedCoupons(const boost::optional<bool>& b) {
+        useIndexedCoupons_ = b;
+        return *this;
+    }
+
+    MakeVanillaSwap& MakeVanillaSwap::withAtParCoupons(bool b) {
+        useIndexedCoupons_ = !b;
+        return *this;
+    }
+
 }
