@@ -107,7 +107,6 @@ namespace inflation_cpi_capfloor_test {
         std::vector<Date> zciisD;
         std::vector<Rate> zciisR;
         ext::shared_ptr<UKRPI> ii;
-        RelinkableHandle<ZeroInflationIndex> hii;
         Size zciisDataLength;
 
         RelinkableHandle<YieldTermStructure> nominalUK;
@@ -265,11 +264,9 @@ namespace inflation_cpi_capfloor_test {
             ext::shared_ptr<PiecewiseZeroInflationCurve<Linear> > pCPIts(
                                 new PiecewiseZeroInflationCurve<Linear>(
                                     evaluationDate, calendar, dcZCIIS, observationLag,
-                                    ii->frequency(),ii->interpolated(), baseZeroRate,
-                                    helpers));
+                                    ii->frequency(), baseZeroRate, helpers));
             pCPIts->recalculate();
             cpiUK.linkTo(pCPIts);
-            hii.linkTo(ii);
 
             // make sure that the index has the latest zero inflation term structure
             hcpi.linkTo(pCPIts);
@@ -338,7 +335,8 @@ void InflationCPICapFloorTest::cpicapfloorpricesurface() {
                        common.calendar,
                        common.convention,
                        common.dcZCIIS,
-                       common.hii,
+                       common.ii,
+                       CPI::Flat,
                        common.nominalUK,
                        common.cStrikesUK,
                        common.fStrikesUK,
@@ -405,7 +403,8 @@ void InflationCPICapFloorTest::cpicapfloorpricer() {
                                                                common.calendar,
                                                                common.convention,
                                                                common.dcZCIIS,
-                                                               common.hii,
+                                                               common.ii,
+                                                               CPI::Flat,
                                                                common.nominalUK,
                                                                common.cStrikesUK,
                                                                common.fStrikesUK,
@@ -423,7 +422,7 @@ void InflationCPICapFloorTest::cpicapfloorpricer() {
     Calendar fixCalendar = UnitedKingdom(), payCalendar = UnitedKingdom();
     BusinessDayConvention fixConvention(Unadjusted), payConvention(ModifiedFollowing);
     Rate strike(0.03);
-    Real baseCPI = common.hii->fixing(fixCalendar.adjust(startDate-common.observationLag,fixConvention));
+    Real baseCPI = common.ii->fixing(fixCalendar.adjust(startDate-common.observationLag,fixConvention));
     CPI::InterpolationType observationInterpolation = CPI::AsIndex;
     CPICapFloor aCap(Option::Call,
                      nominal,
@@ -435,7 +434,7 @@ void InflationCPICapFloorTest::cpicapfloorpricer() {
                      payCalendar,
                      payConvention,
                      strike,
-                     common.hii,
+                     common.ii,
                      common.observationLag,
                      observationInterpolation);
 
