@@ -26,7 +26,7 @@
 #ifdef QL_ENABLE_PARALLEL_UNIT_TEST_RUNNER
 #include "paralleltestrunner.hpp"
 #else
-#include <boost/test/unit_test.hpp>
+#include <boost/test/included/unit_test.hpp>
 #endif
 
 /* Use BOOST_MSVC instead of _MSC_VER since some other vendors (Metrowerks,
@@ -34,11 +34,6 @@
 */
 #if !defined(BOOST_ALL_NO_LIB) && defined(BOOST_MSVC)
 #  include <ql/auto_link.hpp>
-#  ifndef QL_ENABLE_PARALLEL_UNIT_TEST_RUNNER
-#      define BOOST_LIB_NAME boost_unit_test_framework
-#      include <boost/config/auto_link.hpp>
-#      undef BOOST_LIB_NAME
-#  endif
 #endif
 
 #include "utilities.hpp"
@@ -186,6 +181,7 @@
 #include "swingoption.hpp"
 #include "stats.hpp"
 #include "subperiodcoupons.hpp"
+#include "svivolatility.hpp"
 #include "swap.hpp"
 #include "swapforwardmappings.hpp"
 #include "swaption.hpp"
@@ -363,6 +359,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(QUANTLIB_TEST_CASE(startTimer));
 
     test->add(AmericanOptionTest::suite(speed));
+    test->add(AmortizingBondTest::suite());
     test->add(AndreasenHugeVolatilityInterplTest::suite(speed));
     test->add(ArrayTest::suite());
     test->add(AsianOptionTest::suite(speed));
@@ -486,7 +483,6 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(ZeroCouponSwapTest::suite());
 
     // tests for experimental classes
-    test->add(AmortizingBondTest::suite());
     test->add(AsianOptionTest::experimental(speed));
     test->add(BasismodelsTest::suite());
     test->add(BasisSwapRateHelpersTest::suite());
@@ -525,6 +521,7 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(RiskNeutralDensityCalculatorTest::experimental(speed));
     test->add(SpreadOptionTest::suite());
     test->add(SquareRootCLVModelTest::experimental());
+    test->add(SviVolatilityTest::experimental());
     test->add(SwingOptionTest::suite(speed));
     test->add(TwoAssetBarrierOptionTest::suite());
     test->add(TwoAssetCorrelationOptionTest::suite());
